@@ -6,6 +6,8 @@ pub mod alias_dto;
 pub use self::alias_dto::AliasDto;
 pub mod alias_projection;
 pub use self::alias_projection::AliasProjection;
+pub mod attachment_entity;
+pub use self::attachment_entity::AttachmentEntity;
 pub mod attachment_meta_data;
 pub use self::attachment_meta_data::AttachmentMetaData;
 pub mod attachment_projection;
